Documentation
¶
Overview ¶
Package source handles input resolution for clai.
Sources are file paths or stdin. Multiple file sources are resolved concurrently and joined in the order they were specified.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Input ¶
Input handles reading from stdin and resolving input sources.
func (*Input) IsStdinTerminal ¶
IsStdinTerminal reports whether Stdin is an interactive terminal.
Click to show internal directories.
Click to hide internal directories.